@@ -1,23 +1,31 @@
+import io
+
 import sys
 
 from antlr4 import InputStream, CommonTokenStream
 
 from drb import DrbNode
 
-from drb_xquery.XQueryLexer import XQueryLexer
-from drb_xquery.XQueryParser import XQueryParser
-from drb_xquery.drb_xquery_context import DynamicContext
-from drb_xquery.drb_xquery_visitor import DrbQueryVisitor, \
+from .XQueryLexer import XQueryLexer
+from .XQueryParser import XQueryParser
+from .drb_xquery_context import DynamicContext
+from .drb_xquery_visitor import DrbQueryVisitor, \
     DrbXqueryParserErrorListener
 
 
 class DrbXQuery:
 
-    def __init__(self, xquery_string):
+    def __init__(self, xquery):
         self.static_context = None
 
+        if isinstance(xquery, DrbNode):
+            xquery = xquery.get_impl(io.BufferedIOBase)
+
+        if isinstance(xquery, io.BufferedIOBase):
+            xquery = xquery.read().decode()
+
         # init Lexer with query
-        lexer = XQueryLexer(InputStream(xquery_string))
+        lexer = XQueryLexer(InputStream(xquery))
 
         self.stream = CommonTokenStream(lexer)
         self.parser = XQueryParser(self.stream)
