@@ -3,7 +3,7 @@ from typing import Optional, Any
 
 from drb import DrbNode
 
-from drb_xquery.execptions import ErrorXQUERY, DynamicException, \
+from .execptions import ErrorXQUERY, DynamicException, \
     StaticException
 
 
