@@ -5,13 +5,13 @@ from decimal import Decimal
 from drb import DrbNode
 from drb.factory import DrbFactoryResolver
 
-from drb_xquery.drb_xquery_context import DynamicContext, StaticContext
+from .drb_xquery_context import DynamicContext, StaticContext
 import re
 from dateutil.parser import parse
 
-from drb_xquery.drb_xquery_item import DrbXqueryItem
-from drb_xquery.drb_xquery_utils import DrbQueryFuncUtil
-from drb_xquery.execptions import DynamicException, ErrorXQUERY
+from .drb_xquery_item import DrbXqueryItem
+from .drb_xquery_utils import DrbQueryFuncUtil
+from .execptions import DynamicException, ErrorXQUERY
 
 
 def check_arg(func, number_expected, *args):
