@@ -3,13 +3,10 @@ import calendar
 import math
 from decimal import Decimal
 
-from xml.etree import ElementTree
-
 from drb import DrbNode
 
-from drb_impl_xml import XmlNode
-from drb_xquery.drb_xquery_context import DynamicContext
-from drb_xquery.execptions import DynamicException, ErrorXQUERY
+from .drb_xquery_context import DynamicContext
+from .execptions import DynamicException, ErrorXQUERY
 
 
 class DrbQueryFuncUtil:
@@ -150,6 +147,19 @@ class DrbQueryFuncUtil:
         if isinstance(value, (float, Decimal, str)):
             return round(float(value))
 
+    @staticmethod
+    def get_nane(node):
+        if isinstance(node, list):
+            if len(node) == 0:
+                return ''
+            node = node[0]
+        if isinstance(node, DrbNode):
+            return node.name
+        elif isinstance(node, DynamicContext):
+            return node.name
+
+        return ''
+
     @staticmethod
     def get_node(node):
         if isinstance(node, list):
@@ -405,6 +415,17 @@ class DrbQueryFuncUtil:
         else:
             list_object.append(object_to_append)
 
+    @staticmethod
+    def compare_drb(node1: DrbNode, node2: DrbNode) -> bool:
+        if node1 == node2:
+            if len(node1) == len(node2):
+                for index_child in range(len(node1)):
+                    if not DrbQueryFuncUtil.compare_drb(node1[index_child],
+                                                        node2[index_child]):
+                        return False
+                return True
+        return False
+
     @staticmethod
     def compare(node1, node2) -> bool:
         if type(node1) != type(node2):
@@ -421,11 +442,7 @@ class DrbQueryFuncUtil:
         if isinstance(node1, DynamicContext):
             return DrbQueryFuncUtil.compare(node1.node, node2.node)
         elif isinstance(node1, DrbNode):
-            if isinstance(node1, XmlNode):
-                return ElementTree.tostring(node1._elem) \
-                       == ElementTree.tostring(node2._elem)
-            else:
-                return node1 == node2
+            return DrbQueryFuncUtil.compare_drb(node1, node2)
         else:
             return node1 == node2
 
