@@ -10,16 +10,16 @@ from antlr4.tree.Tree import TerminalNodeImpl
 from drb import DrbNode
 from drb.factory import DrbFactoryResolver
 
-from drb_xquery.XQueryLexer import XQueryLexer
-from drb_xquery.XQueryParser import XQueryParser
-from drb_xquery.XQueryParserVisitor import XQueryParserVisitor
-from drb_xquery.drb_xquery_context import AxeNode, \
+from .XQueryLexer import XQueryLexer
+from .XQueryParser import XQueryParser
+from .XQueryParserVisitor import XQueryParserVisitor
+from .drb_xquery_context import AxeNode, \
     DynamicContext, NavigationStep, StaticContext, NamespaceMap
-from drb_xquery.drb_xquery_func import DrbQueryFuncCall
-from drb_xquery.drb_xquery_item import DrbXqueryItem
-from drb_xquery.drb_xquery_utils import DrbQueryFuncUtil
-from drb_xquery.drb_xquery_variable import XqueryVariable, XqueryBuildIn
-from drb_xquery.execptions import DynamicException, ErrorXQUERY, \
+from .drb_xquery_func import DrbQueryFuncCall
+from .drb_xquery_item import DrbXqueryItem
+from .drb_xquery_utils import DrbQueryFuncUtil
+from .drb_xquery_variable import XqueryVariable, XqueryBuildIn
+from .execptions import DynamicException, ErrorXQUERY, \
     StaticException
 
 
@@ -1524,7 +1524,11 @@ class DrbQueryVisitor(XQueryParserVisitor):
         if ctx.KW_IF is None:
             return self.visitChildren(ctx)
 
-        res = self.visitExpr(ctx.expr())
+        visitor = DrbQueryVisitor(self.dynamic_context,
+                                  static_context=self.static_context,
+                                  external_var_map=self.external_var_map,
+                                  tokens=self.tokens)
+        res = visitor.visitExpr(ctx.expr())
         if DrbQueryFuncUtil.get_effective_boolean_value(res):
             return self.visitExprSingle(ctx.thenExpr)
         else:
