@@ -7,6 +7,9 @@ from drb_impl_file import DrbFileFactory
 from drb_impl_xml import XmlNodeFactory
 from drb_xquery import DrbXQuery
 from pathlib import Path
+
+from drb_xquery.drb_xquery_res_to_string import XQueryResToString
+from drb_xquery.drb_xquery_utils import DrbQueryFuncUtil
 from tests.XQueryTest import XQueryTest
 
 X_QUERY_PATH_FILES = 'tests/files/XQTS_1_0_3'
@@ -57,6 +60,7 @@ class XQueryTestXQTS:
         self.node = node
         self.name = self.node.get_attribute("name")
         self.expected_result = []
+        self.expected_xml = None
         self.vars = {}
         self.node_begin = None
         self.error = None
@@ -72,10 +76,15 @@ class XQueryTestXQTS:
             nodes_res = self.node['output-file', :]
             for node_res in nodes_res:
                 file_res = node_res.value
-                self.expected_result.append(Path(X_QUERY_PATH_FILES +
-                                                 '/ExpectedTestResults/' +
-                                                 path_file + '/' +
-                                                 file_res).read_text())
+                file_path = X_QUERY_PATH_FILES + '/ExpectedTestResults/'
+                file_path += path_file + '/' + file_res
+                if file_res.endswith('.xml'):
+                    try:
+                        self.expected_xml = \
+                            XmlNodeFactory().create(source=file_path)
+                    except Exception:
+                        pass
+                self.expected_result.append(Path(file_path).read_text())
 
         if self.node.has_child('input-query'):
             nodes_var = self.node['input-query', :]
@@ -116,9 +125,14 @@ class XQueryTestXQTS:
         if not isinstance(result, list):
             result = [result]
 
+        if len(result) == 1 and self.expected_xml is not None:
+            node = DrbQueryFuncUtil.get_node(result)
+            if DrbQueryFuncUtil.compare_drb(self.expected_xml, node):
+                return True
+
         result_string = None
         for item in result:
-            result_string = XQueryTest.add_item_to_result(
+            result_string = XQueryResToString.add_item_to_result(
                 result_string, item,
                 separator=' ',
                 context=query.static_context,
