@@ -6,7 +6,6 @@ from pathlib import Path
 from drb_impl_file import DrbFileFactory
 from drb_impl_xml import XmlNodeFactory
 from drb_xquery.drb_xquery import DrbXQuery
-from drb_xquery.drb_xquery_utils import DrbQueryFuncUtil
 
 
 class NodeTest:
@@ -396,7 +395,7 @@ class TestDrbXQuery(unittest.TestCase):
 
         self.assertListEqual(node_result, [1, 2, 3, 4, 5])
 
-    def test_xquery_namespace(self):
+    def test_xquery_namespace_bis(self):
         self.node_file = DrbFileFactory().create(self.xml_file)
         self.node = XmlNodeFactory().create(self.node_file)
 
@@ -406,7 +405,7 @@ class TestDrbXQuery(unittest.TestCase):
         self.assertEqual(len(node_result), 1)
         self.assertEqual(len(node_result[0].node['Test_FLF', :]), 6)
 
-    def test_xquery_namespace_bis(self):
+    def test_xquery_namespace_ter(self):
         self.node_file = DrbFileFactory().create(self.xml_file)
         self.node = XmlNodeFactory().create(self.node_file)
 
@@ -497,3 +496,15 @@ class TestDrbXQuery(unittest.TestCase):
         node_result = drb_query.execute(None)
 
         self.assertListEqual(node_result, [False, True])
+
+    def test_xquery_from_node(self):
+        xquery_file = self.current_path / "files" / "xquery_sample.xq"
+        xquery_file = str(xquery_file)
+
+        node_query = DrbFileFactory().create(xquery_file)
+
+        drb_query = DrbXQuery(node_query)
+
+        node_result = drb_query.execute(None)
+
+        self.assertListEqual(node_result, [False, True])
